@@ -5,7 +5,7 @@ from .user import UserResource
 
 @dataclass
 class VisitResource:
-    id: str
+    id: int
     new: bool
     sender: UserResource
     ts: int
